import React from 'react';
import { BrowserRouter, Routes, Route, Navigate } from 'react-router-dom';
import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
import { Toaster } from '@/components/ui/toaster';
import { TooltipProvider } from "@/components/ui/tooltip";
import { ProfileProvider } from '@/contexts/ProfileContext';
import { AnalyticsProvider } from '@/contexts/AnalyticsContext';
import { MicrosoftClarity } from '@/components/analytics/MicrosoftClarity';
import { AnalyticsWrapper } from '@/components/analytics/AnalyticsWrapper';
import Index from '@/pages/Index';
import Categories from '@/pages/Categories';
import Authors from '@/pages/Authors';
import About from '@/pages/About';
import Contact from '@/pages/Contact';
import Privacy from '@/pages/Privacy';
import Terms from '@/pages/Terms';
import FAQ from '@/pages/FAQ';
import Profile from '@/pages/Profile';
import NotFound from '@/pages/NotFound';
import EmailSubscribe from '@/pages/EmailSubscribe';
import QuotePage from '@/pages/QuotePage';
import CategoryPage from '@/pages/CategoryPage';
import Auth from '@/pages/Auth';
import { AuthGuard } from '@/components/auth/AuthGuard';
// Admin layout and admin subpages:
import { AdminLayout } from '@/components/admin/AdminLayout';
import AdminDashboard from '@/pages/admin/AdminDashboard';
import AdminQuotes from '@/pages/admin/AdminQuotes';
import AdminCategories from '@/pages/admin/AdminCategories';
import AdminAuthors from '@/pages/admin/AdminAuthors';
import AdminAnalytics from '@/pages/admin/AdminAnalytics';
import AdminSEOPreview from '@/pages/admin/AdminSEOPreview';
import AdminUsers from '@/pages/admin/AdminUsers';
import AdminSettings from '@/pages/admin/AdminSettings';

const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      staleTime: 5 * 60 * 1000, // 5 minutes default stale time
      gcTime: 10 * 60 * 1000, // 10 minutes default garbage collection time
      refetchOnWindowFocus: false, // Don't refetch on window focus
      refetchOnMount: false, // Don't refetch on mount if data exists
      retry: 1, // Only retry once
    },
    mutations: {
      retry: 1, // Only retry once for mutations
    },
  },
});

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <TooltipProvider>
        <ProfileProvider>
          <AnalyticsProvider>
            {/* Global Analytics Components - Outside Router */}
            <MicrosoftClarity />
            
            <Toaster />
            <BrowserRouter>
              {/* Analytics Wrapper - Inside Router for useLocation access */}
              <AnalyticsWrapper 
                trackClicks={true}
                trackScrolling={true}
                trackFormInteractions={true}
              >
                <Routes>
                  {/* Public Routes */}
                  <Route path="/" element={<Index />} />
                  <Route path="/categories" element={<Categories />} />
                  <Route path="/categories/:categoryName" element={<CategoryPage />} />
                  <Route path="/authors" element={<Authors />} />
                  <Route path="/about" element={<About />} />
                  <Route path="/contact" element={<Contact />} />
                  <Route path="/privacy" element={<Privacy />} />
                  <Route path="/terms" element={<Terms />} />
                  <Route path="/faq" element={<FAQ />} />
                  <Route path="/profile" element={<Profile />} />
                  <Route path="/email-subscribe" element={<EmailSubscribe />} />
                  <Route path="/quote/:id" element={<QuotePage />} />

                  {/* Auth Route */}
                  <Route path="/auth" element={<Auth />} />

                  {/* Admin Route: Nested Admin layout and pages */}
                  <Route path="/admin/*" element={
                    <AuthGuard>
                      <AdminLayout />
                    </AuthGuard>
                  }>
                    <Route index element={<Navigate to="dashboard" replace />} />
                    <Route path="dashboard" element={<AdminDashboard />} />
                    <Route path="quotes" element={<AdminQuotes />} />
                    <Route path="categories" element={<AdminCategories />} />
                    <Route path="authors" element={<AdminAuthors />} />
                    <Route path="analytics" element={<AdminAnalytics />} />
                    <Route path="seo-preview" element={<AdminSEOPreview />} />
                    <Route path="users" element={<AdminUsers />} />
                    <Route path="settings" element={<AdminSettings />} />
                    <Route path="*" element={<NotFound />} />
                  </Route>

                  <Route path="*" element={<NotFound />} />
                </Routes>
              </AnalyticsWrapper>
            </BrowserRouter>
          </AnalyticsProvider>
        </ProfileProvider>
      </TooltipProvider>
    </QueryClientProvider>
  );
}

export default App;
